@@ -34,6 +34,21 @@ describe("file_info", {
   })
 })
 
+describe("file_size", {
+  with_dir_tree(list(
+      "foo" = "test",
+      "bar" = "test2"), {
+      it("returns the correct file size", {
+        expect_equal(file_size("foo"), stats::setNames(file_info("foo")$size, "foo"))
+        expect_equal(file_size("bar"), stats::setNames(file_info("bar")$size, "bar"))
+      })
+      it("returns an object of class fs_bytes, numeric (#4685)", {
+        expect_s3_class(file_size("foo"), c("fs_bytes", "numeric"), exact = TRUE)
+        expect_s3_class(file_size("foo")[], c("fs_bytes", "numeric"), exact = TRUE)
+      })
+  })
+})
+
 # Windows permissions only really allow setting read only, so we will skip
 # the more thorough tests
 if (!is_windows()) {
@@ -141,3 +156,37 @@ describe("file_move", {
     expect_error(file_move("foo", NA), class = "invalid_argument")
   })
 })
+
+describe("file_touch", {
+  it("updates modification_time and access_time", {
+    with_dir_tree("dir", {
+      file_create("foo")
+      now <- Sys.time()
+
+      file_touch("foo", now)
+      old <- file_info("foo")
+
+      file_touch("foo", now + 10, now + 20)
+
+      new <- file_info("foo")
+      expect_true(old$modification_time < new$modification_time)
+      expect_true(old$access_time < new$access_time)
+
+      file_touch("foo", now - 10, now - 20)
+      new2 <- file_info("foo")
+      expect_true(old$modification_time > new2$modification_time)
+      expect_true(old$access_time > new2$access_time)
+    })
+  })
+
+  it("errors on missing input", {
+    expect_error(file_touch(NA), class = "invalid_argument")
+  })
+
+  it("creates the file if it doesn't exist", {
+    with_dir_tree("dir", {
+      file_touch("foo")
+      expect_true(file_exists("foo"))
+    })
+  })
+})
